package com.dgtly.wxportal.controller;

import com.dgtly.common.annotation.ApiPassToken;
import com.dgtly.common.core.controller.ApiBaseController;
import com.dgtly.common.core.domain.AjaxResult;
import com.dgtly.common.core.domain.ParameterObject;
import com.dgtly.system.domain.SysUser;
import com.dgtly.system.service.ICustomersExtService;
import com.dgtly.system.service.ISysUserService;
import com.dgtly.wxportal.domain.OrderFile;
import com.dgtly.wxportal.service.IEsignOrganRealVerifyService;
import com.dgtly.wxportal.service.IEsignPersonRealnVerifyService;
import com.dgtly.wxportal.service.IEsignSignService;
import com.dgtly.wxportal.service.IOrderFileService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @description:e签宝认证
 * @author:qxm
 * @date:2020/10/12 16:18
 */
@Api(tags = "e签宝相关API", description = "提供e签宝服务API")
@RequestMapping("eSign")
@RestController
@ApiPassToken
public class EsignController extends ApiBaseController {

    @Autowired
    private IEsignPersonRealnVerifyService personRealnVerifyService;
    @Autowired
    private IEsignOrganRealVerifyService organRealVerifyService;
    @Autowired
    private IEsignSignService signService;
    @Autowired
    private IOrderFileService orderFileService;
    @Autowired
    private ISysUserService userService;
    @Autowired
    private ICustomersExtService customersExtService;

    /**
     * 经销商订单签收方法
     * 没有注册就注册，注册完就认证，然后再点击签署按钮，获取经销商用户id，对应主体id
     * E签宝一步发起签署
     */
    @ApiOperation(value = "订单签收", notes = "参数：{'orderId':'xxx','signerAccountId':'xxx','authorizedAccountId':'xxx'}" +
            "\n（orderId：订单编号" +
            "\n（signerAccountId：签收人（个人）" +
            "\n authorizedAccountId：签收主体（公司））")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("dealerSign")
    public Object dealerSign() {

        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("orderId,signerAccountId,signerName,authorizedAccountId");
        String orderId = obj.getString("orderId");
        String businessScene = "订单签收";
        String fileName = "签收订单.pdf";
        String signerAccountId = obj.getString("signerAccountId");
        String authorizedAccountId = obj.getString("authorizedAccountId");

        /*首先根据订单id-orderId查询订单是否已被签署*/
        OrderFile orderFlag = orderFileService.selectOrderFileById(orderId);
        if (orderFlag==null) {

            /*1、根据传入订单id，查询订单相关信息生成PDF，调用e签宝上传方法返回文件fileId*/
            String fileId = "f6ada0144a464d7bb90224104d1c4ca3";
            /*2、调用E签宝接口一步发起流程，得到返回的流程id*/
            String flowId = signService.oneStepFlow(businessScene, fileId, fileName, signerAccountId, authorizedAccountId);
            /*3、调用E签宝获取签署地址*/
            String result = signService.processExecuteUrl(flowId, signerAccountId, authorizedAccountId);
            /*4、保存订单id和flowId*/
            OrderFile orderFile = new OrderFile();
            orderFile.setOrderId(orderId);
            orderFile.setCustomersCode(authorizedAccountId);
            orderFile.setSignerId(signerAccountId);
            orderFile.setSignerName("");
            orderFile.setFlowId(flowId);
            orderFileService.insertOrderFile(orderFile);
            return result;
        }else{
            return AjaxResult.error("订单已签署");
        }
    }

    /**
     * 经销商通过签署地址签署后，回调此方法，通过flowId得到签署后的文件下载地址并保存url
     */
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("updateOrderFile")
    public Object updateOrderFile() {
        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("flowId");
        String flowId = obj.getString("flowId");
        String fileUrl = signService.processDocumentDownload(flowId);

        OrderFile orderFile = new OrderFile();
        orderFile.setFlowId(flowId);
        orderFile.setFileUrl(fileUrl);
        orderFileService.updateOrderFileByFlowId(orderFile);
        return fileUrl;
    }


    @ApiOperation(value = "E签宝个人认证", notes = "参数：{'accountId':'XXXXXXX'}" +
            "\n（accountId：待认证账号Id）")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("personRealnVerify")
    public Object personRealnVerify() {
        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("accountId");
        String accountId = obj.getString("accountId");
        String result = personRealnVerifyService.personRealnVerify(accountId);
        return result;
    }

    /*调用修改数据库个人认证状态*/
    @ApiOperation(value = "E签宝个人认证成功回调接口（修改认证状态）",
            notes = "参数：{" +
                    "userId:'123'}" +
                    "错误：" +
                    "500 修改个人认证状态失败" +
                    "")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("updateUerIsAuthentication")
    public Object updateUerIsAuthentication(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("userId");
        String userId = obj.getString("userId");
        int result = userService.updateIsAuthentication("1",userId);
        if (result>0){
            return AjaxResult.success().putKV("result",result);
        }else {
            return AjaxResult.error(500,"修改个人认证状态失败");
        }
    }


    @ApiOperation(value = "E签宝企业认证", notes = "参数：{'accountId':'XXXXXXX','agentAccountId':'XXXXXXXXX'}" +
            "\n（accountId：待认证e签宝企业账号Id,agentAccountId:办理人账号Id）")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("organRealVerify")
    public Object organRealVerify() {
        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("accountId,agentAccountId");
        String accountId = obj.getString("accountId");
        String agentAccountId = obj.getString("agentAccountId");
        String result = organRealVerifyService.organRealVerify(accountId, agentAccountId);
        return result;
    }

    /*调用修改数据库企业认证状态*/
    @ApiOperation(value = "E签宝企业认证成功回调接口（修改认证状态）",
            notes = "参数：{" +
                    "userId:'123'}" +
                    "错误：" +
                    "500 修改企业认证状态失败" +
                    "")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params" , paramType = "body")
    })
    @PostMapping("updateCustomersIsAuthentication")
    public Object updateCustomersIsAuthentication(){
        ParameterObject obj =  getParameterObject();
        obj.checkParameterNotNull("userId");
        Long userId = obj.getLong("userId");
        SysUser user = userService.selectUserById(userId);
        int result = customersExtService.updateCustomersIsAuthentication("1",user.getSysUserExt().getOrgCode());
        if (result>0){
            return AjaxResult.success().putKV("result",result);
        }else {
            return AjaxResult.error(500,"修改企业认证状态失败");
        }
    }


    /*@ApiOperation(value = "E签宝一步发起签署", notes = "参数：{'businessScene':'XXXXXXX','fileId':'XXXXXXXXX','fileName':'xxx.pdf','signerAccountId':'xxx','authorizedAccountId':'xxx'}" +
            "\n ( businessScene:文件主题---xx订单签收" +
            "\n fileId:签署文档id" +
            "\n fileName:签署文件名称（名称可以自定义，必须带上文件扩展名，不然会导致后续发起流程校验过不去 示例：合同.pdf ）" +
            "\n signerAccountId:签署操作人个人账号标识，即操作本次签署的个人" +
            "\n authorizedAccountId:签约主体账号标识，即本次签署对应任务的归属方，默认是签署操作人个人)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("oneStepFlow")
    public Object oneStepFlow() {
        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("businessScene,fileId,fileName,signerAccountId,authorizedAccountId");
        String businessScene = obj.getString("businessScene");
        String fileId = obj.getString("fileId");
        String fileName = obj.getString("fileName");
        String signerAccountId = obj.getString("signerAccountId");
        String authorizedAccountId = obj.getString("authorizedAccountId");
//        String result = signService.oneStepFlow(businessScene,fileId,fileName,signerAccountId,authorizedAccountId);
//        return result;
        return null;
    }

    @ApiOperation(value = "E签宝一步发起签署", notes = "参数：{'flowId':'XXXXXXX'}")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "params", paramType = "body")
    })
    @PostMapping("processDocumentDownload")
    public Object processDocumentDownload() {
        ParameterObject obj = getParameterObject();
        obj.checkParameterNotNull("flowId");
        String flowId = obj.getString("businessScene");
        String result = signService.processDocumentDownload(flowId);
        *//*存入数据库*//*
        return result;
    }*/

}
